﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;
using Syncfusion.ListView.XForms;
using Xamarin.Forms.Internals;
using System.Reflection;

namespace SfListViewSample
{
    [Preserve(AllMembers = true)]
    public class ListViewSelectionViewModel : INotifyPropertyChanged
    {
        #region Fields

        private ObservableCollection<Musiqnfo> musicInfo;
        private ImageSource selectionEdit;
        private ImageSource selectionCancel;
        private string headerInfo;
        private string titleInfo;
        private bool isVisible;

        #endregion

        #region Constructor

        public ListViewSelectionViewModel()
        {
            Assembly assembly = typeof(Selection).GetTypeInfo().Assembly;
            GenerateSource();
            titleInfo = "Music Library";
            headerInfo = "";

            DeleteImage = ImageSource.FromResource("SfListViewSample.Images.Delete.png");
            FavoriteImage = ImageSource.FromResource("SfListViewSample.Images.Favorites.png");
            selectionEdit = ImageSource.FromResource("SfListViewSample.Images.SelectionEdit.png", assembly);
            selectionCancel = ImageSource.FromResource("SfListViewSample.Images.SelectionCancel.png", assembly);
        }

        #endregion

        #region Properties

        public ImageSource DeleteImage { get; set; }
        public ImageSource FavoriteImage { get; set; }
        public ObservableCollection<Musiqnfo> MusicInfo
        {
            get { return musicInfo; }
            set { this.musicInfo = value; }
        }

        public string TitleInfo
        {
            get { return titleInfo; }
            set
            {
                if (titleInfo != value)
                {
                    titleInfo = value;
                    OnPropertyChanged("TitleInfo");
                }
            }
        }

        public bool IsVisible
        {
            get { return isVisible; }
            set
            {
                if (isVisible != value)
                {
                    isVisible = value;
                    OnPropertyChanged("IsVisible");
                }
            }
        }

        public string HeaderInfo
        {
            get { return headerInfo; }
            set
            {
                if (headerInfo != value)
                {
                    headerInfo = value;
                    OnPropertyChanged("HeaderInfo");
                }
            }
        }

        public ImageSource SelectionEdit
        {
            get
            {
                return selectionEdit;
            }
            set
            {
                if (selectionEdit != value)
                {
                    selectionEdit = value;
                    OnPropertyChanged("SelectionEdit");
                }
            }
        }

        public ImageSource SelectionCancel
        {
            get
            {
                return selectionCancel;
            }
            set
            {
                if (selectionCancel != value)
                {
                    selectionCancel = value;
                    OnPropertyChanged("SelectionCancel");
                }
            }
        }

        #endregion

        #region Generate Source

        private void GenerateSource()
        {
            MusiqInfoRepository musiqinfo = new MusiqInfoRepository();
            musicInfo = musiqinfo.GetMusiqInfo();
        }

        #endregion

        #region INotifyPropertyChanged

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }

        #endregion
    }
}
